==> jc-1.4.0.tar.gz: gnu/java/nio/NIOSocket.h <==
// public final class gnu.java.nio.NIOSocket

// class file dependencies
// @dep_class 77c58afb0ca1b4da gnu_java_nio_NIOSocket
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c62a12eb19f8bf2e java_net_Socket

// header file dependencies
// @dep_header java_net_Socket

#include "java/net/Socket.h"

#ifndef _JC_gnu_java_nio_NIOSocket_H_
#define _JC_gnu_java_nio_NIOSocket_H_

// Forward structure declarations
struct _jc_gnu_java_net_PlainSocketImpl$object;
struct _jc_gnu_java_nio_SocketChannelImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_SocketChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_NIOSocket$sub_refs	_jc_gnu_java_nio_NIOSocket$sub_refs;
typedef struct _jc_gnu_java_nio_NIOSocket$sub_nonrefs	_jc_gnu_java_nio_NIOSocket$sub_nonrefs;
typedef struct _jc_gnu_java_nio_NIOSocket$refs	_jc_gnu_java_nio_NIOSocket$refs;
typedef struct _jc_gnu_java_nio_NIOSocket$nonrefs	_jc_gnu_java_nio_NIOSocket$nonrefs;
typedef struct _jc_gnu_java_nio_NIOSocket$object	_jc_gnu_java_nio_NIOSocket$object;

typedef const struct _jc_gnu_java_nio_NIOSocket$vmethods	_jc_gnu_java_nio_NIOSocket$vmethods;
typedef const struct _jc_gnu_java_nio_NIOSocket$vtable	_jc_gnu_java_nio_NIOSocket$vtable;
typedef const struct _jc_gnu_java_nio_NIOSocket$vtype	_jc_gnu_java_nio_NIOSocket$vtype;

// Constructors
extern void _jc_gnu_java_nio_NIOSocket$method$_init$89e487c441983712(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *, struct _jc_gnu_java_net_PlainSocketImpl$object *, struct _jc_gnu_java_nio_SocketChannelImpl$object *);

// Virtual methods
extern struct _jc_java_nio_channels_SocketChannel$object *_jc_gnu_java_nio_NIOSocket$method$getChannel$f6b45f65c73d7320(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *);
extern struct _jc_gnu_java_net_PlainSocketImpl$object *_jc_gnu_java_nio_NIOSocket$method$getPlainSocketImpl$9130f35e50042eea(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *);
extern void _jc_gnu_java_nio_NIOSocket$method$setChannel$7db0420bd7a0f4ef(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *, struct _jc_gnu_java_nio_SocketChannelImpl$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_NIOSocket$method_info$getChannel$f6b45f65c73d7320;
extern _jc_method _jc_gnu_java_nio_NIOSocket$method_info$getPlainSocketImpl$9130f35e50042eea;
extern _jc_method _jc_gnu_java_nio_NIOSocket$method_info$setChannel$7db0420bd7a0f4ef;

// Virtual methods structure
struct _jc_gnu_java_nio_NIOSocket$vmethods {
	struct _jc_java_nio_channels_SocketChannel$object	*(*getChannel$f6b45f65c73d7320)(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *);
	struct _jc_gnu_java_net_PlainSocketImpl$object	*(*getPlainSocketImpl$9130f35e50042eea)(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *);
	void	(*setChannel$7db0420bd7a0f4ef)(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *, struct _jc_gnu_java_nio_SocketChannelImpl$object *);
};

// Vtable
struct _jc_gnu_java_nio_NIOSocket$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_Socket$vmethods	java_net_Socket;
	_jc_gnu_java_nio_NIOSocket$vmethods	gnu_java_nio_NIOSocket;
};

// Vtype
struct _jc_gnu_java_nio_NIOSocket$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_NIOSocket$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_NIOSocket$sub_refs {
	struct _jc_gnu_java_net_PlainSocketImpl$object	*impl;
	struct _jc_gnu_java_nio_SocketChannelImpl$object	*channel;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_NIOSocket$refs {
    _jc_gnu_java_nio_NIOSocket$sub_refs	gnu_java_nio_NIOSocket;
    _jc_java_net_Socket$sub_refs	java_net_Socket;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_NIOSocket$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_NIOSocket$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_Socket$sub_nonrefs	java_net_Socket;
    _jc_gnu_java_nio_NIOSocket$sub_nonrefs	gnu_java_nio_NIOSocket;
};

// Object instance structure
struct _jc_gnu_java_nio_NIOSocket$object {
	_jc_gnu_java_nio_NIOSocket$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_NIOSocket$vtype	*vtype;
	_jc_gnu_java_nio_NIOSocket$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_NIOSocket$vtype _jc_gnu_java_nio_NIOSocket$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_NIOSocket, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_NIOSocket$class_object;

#endif	/* _JC_gnu_java_nio_NIOSocket_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/NIOSocket.h <==
// public final class gnu.java.nio.NIOSocket

// class file dependencies
// @dep_class 77c58afb0ca1b4da gnu_java_nio_NIOSocket
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c62a12eb19f8bf2e java_net_Socket

// header file dependencies
// @dep_header java_net_Socket

#include "java/net/Socket.h"

#ifndef _JC_gnu_java_nio_NIOSocket_H_
#define _JC_gnu_java_nio_NIOSocket_H_

// Forward structure declarations
struct _jc_gnu_java_net_PlainSocketImpl$object;
struct _jc_gnu_java_nio_SocketChannelImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_SocketChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_NIOSocket$sub_refs	_jc_gnu_java_nio_NIOSocket$sub_refs;
typedef struct _jc_gnu_java_nio_NIOSocket$sub_nonrefs	_jc_gnu_java_nio_NIOSocket$sub_nonrefs;
typedef struct _jc_gnu_java_nio_NIOSocket$refs	_jc_gnu_java_nio_NIOSocket$refs;
typedef struct _jc_gnu_java_nio_NIOSocket$nonrefs	_jc_gnu_java_nio_NIOSocket$nonrefs;
typedef struct _jc_gnu_java_nio_NIOSocket$object	_jc_gnu_java_nio_NIOSocket$object;

typedef const struct _jc_gnu_java_nio_NIOSocket$vmethods	_jc_gnu_java_nio_NIOSocket$vmethods;
typedef const struct _jc_gnu_java_nio_NIOSocket$vtable	_jc_gnu_java_nio_NIOSocket$vtable;
typedef const struct _jc_gnu_java_nio_NIOSocket$vtype	_jc_gnu_java_nio_NIOSocket$vtype;

// Constructors
extern void _jc_gnu_java_nio_NIOSocket$method$_init$89e487c441983712(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *, struct _jc_gnu_java_net_PlainSocketImpl$object *, struct _jc_gnu_java_nio_SocketChannelImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_channels_SocketChannel$object *_jc_gnu_java_nio_NIOSocket$method$getChannel$f6b45f65c73d7320(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_net_PlainSocketImpl$object *_jc_gnu_java_nio_NIOSocket$method$getPlainSocketImpl$9130f35e50042eea(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_NIOSocket$method$setChannel$7db0420bd7a0f4ef(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *, struct _jc_gnu_java_nio_SocketChannelImpl$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_NIOSocket$method_info$getChannel$f6b45f65c73d7320;
extern _jc_method _jc_gnu_java_nio_NIOSocket$method_info$getPlainSocketImpl$9130f35e50042eea;
extern _jc_method _jc_gnu_java_nio_NIOSocket$method_info$setChannel$7db0420bd7a0f4ef;

// Virtual methods structure
struct _jc_gnu_java_nio_NIOSocket$vmethods {
	struct _jc_java_nio_channels_SocketChannel$object	*(*getChannel$f6b45f65c73d7320)(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_java_net_PlainSocketImpl$object	*(*getPlainSocketImpl$9130f35e50042eea)(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *) _JC_JCNI_ATTR;
	void	(*setChannel$7db0420bd7a0f4ef)(_jc_env *, struct _jc_gnu_java_nio_NIOSocket$object *, struct _jc_gnu_java_nio_SocketChannelImpl$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_NIOSocket$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_Socket$vmethods	java_net_Socket;
	_jc_gnu_java_nio_NIOSocket$vmethods	gnu_java_nio_NIOSocket;
};

// Vtype
struct _jc_gnu_java_nio_NIOSocket$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_NIOSocket$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_NIOSocket$sub_refs {
	struct _jc_gnu_java_net_PlainSocketImpl$object	*impl;
	struct _jc_gnu_java_nio_SocketChannelImpl$object	*channel;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_NIOSocket$refs {
    _jc_gnu_java_nio_NIOSocket$sub_refs	gnu_java_nio_NIOSocket;
    _jc_java_net_Socket$sub_refs	java_net_Socket;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_NIOSocket$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_NIOSocket$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_Socket$sub_nonrefs	java_net_Socket;
    _jc_gnu_java_nio_NIOSocket$sub_nonrefs	gnu_java_nio_NIOSocket;
};

// Object instance structure
struct _jc_gnu_java_nio_NIOSocket$object {
	_jc_gnu_java_nio_NIOSocket$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_NIOSocket$vtype	*vtype;
	_jc_gnu_java_nio_NIOSocket$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_NIOSocket$vtype _jc_gnu_java_nio_NIOSocket$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_NIOSocket, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_NIOSocket$class_object;

#endif	/* _JC_gnu_java_nio_NIOSocket_H_ */
